cumulusci.tasks.release\_notes package
======================================

Subpackages
-----------

.. toctree::

   cumulusci.tasks.release_notes.tests

Submodules
----------


.. automodule:: cumulusci.tasks.release_notes.exceptions
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.release_notes.generator
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.release_notes.parser
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.release_notes.provider
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.release_notes.task
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.release_notes
   :members:
   :undoc-members:
   :show-inheritance:
